@@ -454,15 +454,19 @@ void FluxWidget::paintGL()
 
     if(dBlur)   // partially
     {
+        int viewport[4];
+        glGetIntegerv(GL_VIEWPORT, viewport);
+        float viewRatio = float(viewport[2]) / float(viewport[3]);
+
         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
         glEnable(GL_BLEND);
         glDisable(GL_DEPTH_TEST);
         glColor4f(0.0f, 0.0f, 0.0f, 0.5f - (float(sqrt(sqrt(double(dBlur)))) * 0.15495f));
         glBegin(GL_TRIANGLE_STRIP);
-            glVertex3f(-5.0f, -4.0f, 0.0f);
-            glVertex3f(5.0f, -4.0f, 0.0f);
-            glVertex3f(-5.0f, 4.0f, 0.0f);
-            glVertex3f(5.0f, 4.0f, 0.0f);
+            glVertex3f(-3.0f * viewRatio, -3.0f, 0.0f);
+            glVertex3f(3.0f * viewRatio, -3.0f, 0.0f);
+            glVertex3f(-3.0f * viewRatio, 3.0f, 0.0f);
+            glVertex3f(3.0f * viewRatio, 3.0f, 0.0f);
         glEnd();
     }
     else  // completely
