@@ -74,11 +74,6 @@ extern "C"
 //=============================================================================
 kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
 {
-  time_t t;
-
-  time(&t);
-  srand((unsigned int)t);
-
   KImageIO::registerFormats();
 
   blank();
@@ -199,7 +194,7 @@ int kSlideShowSaver::effectMultiCircleOut(bool aInit)
     pa.setPoint(0, mw>>1, mh>>1);
     pa.setPoint(3, mw>>1, mh>>1);
     mfy = sqrt((double)mw*mw + mh*mh) / 2;
-    mi  = rand()%15 + 2;
+    mi  = KApplication::random()%15 + 2;
     mfd = M_PI*2/mi;
     mAlpha = mfd;
     mwait = 10 * mi;
@@ -325,7 +320,7 @@ int kSlideShowSaver::effectMeltdown(bool aInit)
     y = mIntArray[i];
     if (y >= mh) continue;
     done = false;
-    if ((rand()&15) < 6) continue;
+    if ((KApplication::random()&15) < 6) continue;
     bitBlt(this, x, y+mdy, this, x, y, mdx, mh-y-mdy, CopyROP, true);
     bitBlt(this, x, y, &mNextScreen, x, y, mdx, mdy, CopyROP, true);
     mIntArray[i] += mdy;
@@ -393,7 +388,7 @@ int kSlideShowSaver::effectSweep(bool aInit)
   {
     // subtype: 0=sweep right to left, 1=sweep left to right
     //          2=sweep bottom to top, 3=sweep top to bottom
-    mSubType = rand() % 4;
+    mSubType = KApplication::random() % 4;
     mw  = width();
     mh  = height();
     mdx = (mSubType==1 ? 16 : -16);
@@ -456,9 +451,9 @@ int kSlideShowSaver::effectBlobs(bool aInit)
     return -1;
   }
 
-  mx = rand() % mw;
-  my = rand() % mh;
-  r = (rand() % 200) + 50;
+  mx = KApplication::random() % mw;
+  my = KApplication::random() % mh;
+  r = (KApplication::random() % 200) + 50;
 
   mPainter.drawEllipse(mx-r, my-r, r, r);
   mi--;
@@ -472,7 +467,7 @@ int kSlideShowSaver::effectRandom(bool /*aInit*/)
 {
   int x, y, i, w, h, fact, sz;
 
-  fact = (rand() % 3) + 1;
+  fact = (KApplication::random() % 3) + 1;
 
   w = width() >> fact;
   h = height() >> fact;
@@ -480,8 +475,8 @@ int kSlideShowSaver::effectRandom(bool /*aInit*/)
 
   for (i = (w*h)<<1; i > 0; i--)
   {
-    x = (rand() % w) << fact;
-    y = (rand() % h) << fact;
+    x = (KApplication::random() % w) << fact;
+    y = (KApplication::random() % h) << fact;
     bitBlt(this, x, y, &mNextScreen, x, y, sz, sz, CopyROP, true);
   }
   showNextScreen();
@@ -577,7 +572,7 @@ int kSlideShowSaver::effectIncomingEdges(bool aInit)
     mfx = mix / 100.0;
     mfy = miy / 100.0;
     mi = 0;
-    mSubType = rand() & 1;
+    mSubType = KApplication::random() & 1;
   }
 
   mx = (int)(mfx * mi);
@@ -702,7 +697,7 @@ void kSlideShowSaver::slotTimeout()
     loadNextImage();
     createNextScreen();
 
-    if (mNumEffects > 1) i = rand() % mNumEffects;
+    if (mNumEffects > 1) i = KApplication::random() % mNumEffects;
     else i = 0;
 
     mEffect = mEffectList[i];
@@ -753,7 +748,7 @@ void kSlideShowSaver::createNextScreen()
   if (mFileList.isEmpty())
   {
     p.setPen(QColor("white"));
-    p.drawText(20 + (rand() % (ww>>1)), 20 + (rand() % (wh>>1)),
+    p.drawText(20 + (KApplication::random() % (ww>>1)), 20 + (KApplication::random() % (wh>>1)),
 	       i18n("No images found"));
   }
   else
@@ -794,8 +789,8 @@ void kSlideShowSaver::createNextScreen()
       {
         if(mRandomPosition)
         {
-            x = (rand() % (ww - iw)) + geoptr->mXorg;
-            y = (rand() % (wh - ih)) + geoptr->mYorg;
+            x = (KApplication::random() % (ww - iw)) + geoptr->mXorg;
+            y = (KApplication::random() % (wh - ih)) + geoptr->mYorg;
         }
         else
         {
@@ -837,7 +832,7 @@ void kSlideShowSaver::loadNextImage()
 
   if (mShowRandom)
   {
-    mFileIdx = rand() % num;
+    mFileIdx = KApplication::random() % num;
     fname = mFileList[mFileIdx];
     mFileList.remove(fname);
     if (num == 1) //we're about to run out of images
