@@ -1,6 +1,7 @@
 /* Slide Show Screen Saver
  * (C) 1999 Stefan Taferner <taferner@kde.org>
- */                     
+ * (C) 2003 Sven Leiber <s.leiber@web.de>
+ */
 
 
 #ifndef SLIDESHOW_H
@@ -8,20 +9,17 @@
 
 #include <qtimer.h>
 #include <qptrlist.h>
-#include <qdialog.h>
 #include <qstringlist.h>
 #include <qpixmap.h>
-#include <qwidget.h>
 #include <qpainter.h>
 #include <qimage.h>
+
 #include <kscreensaver.h>
+#include <kdialogbase.h>
 
-class kSlideShowSaver;
-class QCheckBox;
-class QSlider;
-class KURLRequester;
-class QLabel;
+#include "slideshowcfg.h"
 
+class SlideShowCfg;
 
 //-----------------------------------------------------------------------------
 class kSlideShowSaver: public KScreenSaver
@@ -43,14 +41,14 @@ protected slots:
 protected:
   void blank();
 
-  /** Load list of images from file */
-  virtual void loadFileList(const QCString &fileName);
-
   /** Load list of images from directory */
   virtual void loadDirectory();
 
+  /** Helper for loadDirectory() */
+  virtual void traverseDirectory(const QString &dirName);
+
   /** Load next image from list. If the file cannot be read
-	   it is automatically removed from the file list. 
+	   it is automatically removed from the file list.
 		mImage contains the image after loading. */
   virtual void loadNextImage();
 
@@ -87,6 +85,14 @@ protected:
   void startPainter(Qt::PenStyle penStyle=NoPen);
 
 protected:
+  struct mScreenGeo {
+    mScreenGeo(int w, int h, int x, int y) : mW(w), mH(h), mXorg(x), mYorg(y) {};
+    int mW;
+    int mH;
+    int mXorg;
+    int mYorg;
+  };
+  QPtrList<mScreenGeo> mGeoList;
   bool mEffectRunning;
   QTimer mTimer;
   int mColorContext;
@@ -105,6 +111,8 @@ protected:
   bool mShowRandom;
   bool mZoomImages;
   bool mPrintName;
+  bool mSubdirectory;
+  bool mRandomPosition;
   int mDelay;
   QString mDirectory;
 
@@ -117,30 +125,25 @@ protected:
 
 
 //-----------------------------------------------------------------------------
-class kSlideShowSetup : public QDialog
+class kSlideShowSetup : public KDialogBase
 {
   Q_OBJECT
 public:
   kSlideShowSetup(QWidget *parent=NULL, const char *name=NULL);
-  void minSize(QWidget* aWidget);
+  ~kSlideShowSetup();
 
 protected:
   void readSettings();
 
 protected slots:
-  void slotOkPressed();
-  void slotAbout();
+  void slotOk();
+  void slotHelp();
   void writeSettings();
   void slotDirSelected(const QString &where);
-  void slotDelay(int);
 
 private:
-  QWidget *mPreview;
   kSlideShowSaver *mSaver;
-  QCheckBox *mCbxRandom, *mCbxZoom, *mCbxShowName;
-  KURLRequester *mDirChooser;
-  QSlider *mDelay;
-  QLabel *mLblDelay;
+  SlideShowCfg *cfg;
 };
 
 #endif /*SLIDESHOW_H*/
