@@ -16,8 +16,8 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 // This file contains code copied from xscreensaver.  The xscreensaver
 // copyright notice follows.
@@ -113,10 +113,14 @@ bool KXSConfigDialog::create()
 	mConfigItemList = *xmlParser.items();
 	QWidget *spacer = new QWidget(controlLayout);
 	controlLayout->setStretchFactor(spacer, 1 );
-	if ( !xmlParser.description().isEmpty() ) {
-	    QLabel *l = new QLabel( xmlParser.description(), plainPage() );
-	    topLayout->addWidget( l );
-	}
+	QString descr = xmlParser.description();
+	if ( !descr.isEmpty() ) {
+	    descr.replace('\n',' ');
+	    descr = descr.simplifyWhiteSpace();
+	    QLabel *l = new QLabel( i18n( descr.utf8() ), plainPage() );
+	    l->setAlignment ( WordBreak );
+ 	    topLayout->addWidget( l );
+ 	}
     } else {
         // fall back to KDE's old config files.
 	int idx = 0;
@@ -187,7 +191,7 @@ bool KXSConfigDialog::create()
 KXSConfigDialog::~KXSConfigDialog()
 {
   if (mPreviewProc && mPreviewProc->isRunning()) {
-    int pid = mPreviewProc->getPid();
+    int pid = mPreviewProc->pid();
     mPreviewProc->kill();
     waitpid(pid, (int *)0, 0);
     delete mPreviewProc;
@@ -307,11 +311,11 @@ void KXSConfigDialog::slotCancel()
 
 //===========================================================================
 
-static const char *appName = "kxsconfig";
+static const char appName[] = "kxsconfig";
 
-static const char *description = I18N_NOOP("KDE X Screen Saver Configuration tool");
+static const char description[] = I18N_NOOP("KDE X Screen Saver Configuration tool");
 
-static const char *version = "3.0.0";
+static const char version[] = "3.0.0";
 
 static const KCmdLineOptions options[] =
 {
@@ -331,7 +335,7 @@ XrmDatabase db;
 
 int main(int argc, char *argv[])
 {
-  KCmdLineArgs::init(argc, argv, appName, description, version);
+  KCmdLineArgs::init(argc, argv, appName, I18N_NOOP("KXSConfig"), description, version);
 
   KCmdLineArgs::addCmdLineOptions(options);
 
