@@ -6,23 +6,33 @@
 #include <qbutton.h>
 
 #include <kpixmap.h>
-#include "kdecoration.h"
-#include "kdecorationfactory.h"
+#include <kdecoration.h>
+#include <kdecorationfactory.h>
 
 
 class QLabel;
 class QSpacerItem;
+class QBoxLayout;
 
 namespace System {
 
 class SystemButton;
 
+enum ButtonType {
+    ButtonClose=0,
+    ButtonSticky,
+    ButtonMinimize,
+    ButtonMaximize,
+    ButtonHelp,
+    ButtonTypeCount
+};
+
 class SystemClient : public KDecoration
 {
    Q_OBJECT
    public:
       SystemClient(KDecorationBridge* bridge, KDecorationFactory* factory);
-      ~SystemClient(){}
+      ~SystemClient();
       virtual Position mousePosition(const QPoint& p) const;
       virtual void resize(const QSize&);
       virtual bool eventFilter(QObject* o, QEvent* e);
@@ -42,13 +52,16 @@ class SystemClient : public KDecoration
       void paintEvent( QPaintEvent* );
       void showEvent( QShowEvent* );
       void mouseDoubleClickEvent( QMouseEvent * );
+      void wheelEvent(QWheelEvent *e);
       void doShape();
       void recalcTitleBuffer();
+   private:
+      void addButtons(QBoxLayout* hb, const QString& buttons);
    private slots:
       void maxButtonClicked();
 
    private:
-      SystemButton* button[5];
+      SystemButton* button[ButtonTypeCount];
       QSpacerItem* titlebar;
       QPixmap titleBuffer;
       QString oldTitle;
@@ -85,6 +98,7 @@ class SystemDecoFactory : public QObject, public KDecorationFactory
       virtual ~SystemDecoFactory();
       virtual KDecoration *createDecoration(KDecorationBridge *);
       virtual bool reset(unsigned long);
+      virtual bool supports( Ability ability );
       virtual QValueList< BorderSize > borderSizes() const;
    private:
       void readConfig();
